"""Reserved words for jsonvl schemas."""


class ReservedWords:
    """Reserved words related to type definitions and constraints."""

    ALL = 'all'
    ATTRIBUTES = 'attr'
    CONSTRAINTS = 'cons'
    DEFS = 'defs'
    ELEMENT = 'elem'
    TYPE = 'type'


class ReservedSymbols:
    """Reserved symbols related to type definitions and constraints."""

    REF = '#'
